@@ -530,8 +530,11 @@ void KDirListerCache::forgetDirs( KDirLister *lister )
 static bool manually_mounted(const QString& path, const KMountPoint::List& possibleMountPoints)
 {
     KMountPoint::Ptr mp = possibleMountPoints.findByPath(path);
-    if (!mp) // not listed in fstab -> yes, manually mounted
+    if (!mp) { // not listed in fstab -> yes, manually mounted
+        if (possibleMountPoints.isEmpty()) // no fstab at all -> don't assume anything
+            return false;
         return true;
+    }
     const bool supermount = mp->mountType() == "supermount";
     if (supermount) {
         return true;
@@ -649,8 +652,14 @@ void KDirListerCache::updateDirectory( const KUrl& _dir )
     kDebug(7004) << _dir;
 
     QString urlStr = _dir.url(KUrl::RemoveTrailingSlash);
-    if ( !checkUpdate( urlStr ) )
+    if (!checkUpdate(urlStr)) {
+        if (_dir.isLocalFile() && findByUrl(0, _dir)) {
+            pendingUpdates.insert(_dir.toLocalFile());
+            if (!pendingUpdateTimer.isActive())
+                pendingUpdateTimer.start(500);
+        }
         return;
+    }
 
     // A job can be running to
     //   - only list a new directory: the listers are in listersCurrentlyListing
