@@ -1226,13 +1226,9 @@ QByteArray KSSLCertificate::toNetscape() {
     fclose(ktf_fs);
 
     QFile qf(ktf.fileName());
-    qf.open(QIODevice::ReadOnly);
-    char *buf = new char[qf.size()];
-    qf.read(buf, qf.size());
-    qba = QByteArray(buf, qf.size());
-    qf.close();
-    delete[] buf;
-
+    if (qf.open(QIODevice::ReadOnly)) {
+        qba = qf.readAll();
+    }
 #endif
 return qba;
 }
@@ -1305,7 +1301,9 @@ QStringList KSSLCertificate::subjAltNames() const {
         }
 
         QString s = (const char *)d->kossl->ASN1_STRING_data(val->d.ia5);
-        if (!s.isEmpty()) {
+        if (!s.isEmpty()  &&
+                /* skip subjectAltNames with embedded NULs */
+                s.length() == d->kossl->ASN1_STRING_length(val->d.ia5)) {
             rc += s;
         }
     }
